BOPTEST
-------

This section describes the BOPTEST integration in Beobench.

Resources
^^^^^^^^^

- Main repository: https://github.com/ibpsa/project1-boptest
- Gym repository: https://github.com/ibpsa/project1-boptest-gym

Licensing
^^^^^^^^^

All code in the ``beobench_contrib/gyms/boptest`` directory is covered by the standard beobench_contrib license.